Package: smfa
Title: Stochastic Metafrontier Analysis
Version: 1.0.0
Authors@R: c(
    person("Sulman Olieko", "Owili", email = "oliekosulman@gmail.com",
           role = c("aut", "cre"),
           comment = c(ORCID = "0000-0001-7401-5326"))
  )
Description: Implements stochastic metafrontier analysis for productivity and
    performance benchmarking across firms operating under different
    technologies. Contains routines for the deterministic metafrontier envelope
    of O'Donnell et al. (2008) <doi:10.1007/s00181-007-0119-4> via linear and
    quadratic programming, and the stochastic metafrontier of Huang et al.
    (2014) <doi:10.1007/s11123-014-0402-2>. Also supports latent class
    stochastic metafrontier analysis and sample selection correction stochastic
    metafrontier models. Depends on the 'sfaR' package by Dakpo et al. (2023)
    <https://CRAN.R-project.org/package=sfaR>.
License: GPL (>= 3)
URL: https://github.com/SulmanOlieko/smfa,
        https://SulmanOlieko.github.io/smfa/
BugReports: https://github.com/SulmanOlieko/smfa/issues
Depends: R (>= 3.5.0), sfaR
Imports: stats
Suggests: knitr, rmarkdown, pkgdown, lmtest
VignetteBuilder: knitr
Config/Needs/website: pkgdown
Encoding: UTF-8
Language: en-US
RoxygenNote: 7.3.3
NeedsCompilation: no
Packaged: 2026-04-24 14:26:20 UTC; macbookpro
Author: Sulman Olieko Owili [aut, cre] (ORCID:
    <https://orcid.org/0000-0001-7401-5326>)
Maintainer: Sulman Olieko Owili <oliekosulman@gmail.com>
Repository: CRAN
Date/Publication: 2026-04-28 19:00:02 UTC
Built: R 4.6.0; ; 2026-04-28 20:32:21 UTC; unix
