# Generated by roxygen2: do not edit by hand

S3method(coef,smfa)
S3method(coef,summary.smfa)
S3method(efficiencies,smfa)
S3method(fitted,smfa)
S3method(ic,smfa)
S3method(logLik,smfa)
S3method(nobs,smfa)
S3method(print,smfa)
S3method(print,summary.smfa)
S3method(residuals,smfa)
S3method(summary,smfa)
S3method(vcov,smfa)
export(smfa)
importFrom(sfaR,efficiencies)
importFrom(sfaR,ic)
importFrom(sfaR,sfacross)
importFrom(sfaR,sfalcmcross)
importFrom(sfaR,sfaselectioncross)
importFrom(stats,as.formula)
importFrom(stats,coef)
importFrom(stats,fitted)
importFrom(stats,lm)
importFrom(stats,logLik)
importFrom(stats,model.frame)
importFrom(stats,model.matrix)
importFrom(stats,model.response)
importFrom(stats,na.pass)
importFrom(stats,nobs)
importFrom(stats,pchisq)
importFrom(stats,pnorm)
importFrom(stats,printCoefmat)
importFrom(stats,qchisq)
importFrom(stats,residuals)
importFrom(stats,setNames)
importFrom(stats,terms)
importFrom(stats,uniroot)
importFrom(stats,update)
importFrom(stats,vcov)
importFrom(utils,capture.output)
